
==========================
Leonardo leonardo-ckeditor
==========================

CKEditor for Leonardo CMS

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-ckeditor

Read More
=========

* https://github.com/django-leonardo/django-leonardo
